{% extends "bee_django_course_simple/user_base.html" %}
{% load bee_django_course_simple_filter %}
{% load bootstrap3 %}
{% block content %}

    <h4>当前还没有课程,或该课程没有内容，请联系客服</h4>

{% endblock content %}